@@ -4,20 +4,20 @@ use strict;
 use vars qw/$VERSION @ISA %authorname/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.01';
+$VERSION = '0.02';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 # registered authornames
 %authorname = (
-	'000001' => 'Milan Sorm <sorm@pef.mendelu.cz>',
-	'000002' => 'Frantisek Darena <darena@pef.mendelu.cz>'
+	'000001' => 'Ing. Milan Sorm <sorm@pef.mendelu.cz>',
+	'000002' => 'Ing. Frantisek Darena <darena@pef.mendelu.cz>'
 );
 
 1;
 
-sub IDENTIFICATION { return "000001-000012-000001"; }
+sub IDENTIFICATION { return "000001-000012-000002"; }
 
-sub author { return 'Milan Sorm <sorm@pef.mendelu.cz>'; }
+sub author { return 'Ing. Milan Sorm <sorm@pef.mendelu.cz>'; }
 
 sub preference { return 0; }
 
