@@ -4,12 +4,12 @@ use strict;
 use vars qw/$VERSION @ISA/;
 use DBIx::dbMan::Extension;
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 @ISA = qw/DBIx::dbMan::Extension/;
 
 1;
 
-sub IDENTIFICATION { return "000001-000009-000002"; }
+sub IDENTIFICATION { return "000001-000009-000003"; }
 
 sub preference { return 1000; }
 
@@ -17,9 +17,10 @@ sub handle_action {
 	my ($obj,%action) = @_;
 
 	if ($action{action} eq 'COMMAND') {
-		if ($action{cmd} =~ /^help$/i) {
+		if ($action{cmd} =~ /^help(?:\s+(.+))?$/i) {
 			$action{action} = 'HELP';
 			$action{type} = 'commands';
+			$action{what} = $1;
 		}
 	}
 
